import React from "react";
export declare type FieldProps<V = object> = {
    pristine: boolean;
    value: any;
    initialValue: any;
    touched: boolean;
    valid: boolean;
    error: null | string;
    values: any;
    disabled: boolean;
    name: string;
};
export declare type FieldRenderer<D = object | undefined> = React.FC<FieldProps & {
    onChange: (value: any) => void;
    initializing: boolean;
    forceError?: boolean;
    className?: string;
    data?: D;
}>;
export declare type BaseFieldComponent = React.FC<{
    name: string;
    component: FieldRenderer;
    validate?: FieldValidator;
    data?: object;
    className?: string;
}>;
export declare type SubmitSuccessResult<R = object> = R extends string ? string : R;
export declare type SubmitErrorResult<R = object> = R extends string ? string : R;
export declare type SubmitSuccessComponent<R = any> = React.FC<{
    result: SubmitSuccessResult<R>;
}>;
export declare type SubmitErrorComponent<R = any> = React.FC<{
    result: SubmitErrorResult<R>;
}>;
export declare type SubmitCallback<V = object, R = object | string> = (values: V, initialValues?: V) => Promise<SubmitSuccessResult<R>> | SubmitSuccessResult<R>;
export declare type ValidateCallback<V = object> = (values: V, initialValues?: V) => PossibleErrors<V> | Promise<PossibleErrors<V>> | null;
export declare type AvailabilityCallback<V = object> = (values: V, initialValues?: V) => null | boolean | {
    [key in keyof V]?: boolean;
};
export declare type Initializer<V = object> = V | Promise<V>;
export declare type FieldValidator = <V>(value: any, name?: keyof V, initialValue?: any, values?: V, initialValues?: V) => string | void | null;
export declare type PossibleErrors<V> = {
    [key in keyof V]?: string;
};
